pub struct ProvenanceEvent {
pub provenance_uuid: Uuid,
pub operation_uuid: Uuid,
pub event_kind: EventKind,
pub actor_uuid: Option<Uuid>,
pub recorded_at_micros: i64,
pub contract_version: u32,
}Expand description
One immutable provenance event.
Fields
provenance_uuid: UuidDeterministic UUIDv8 derived from the canonical event.
operation_uuid: UuidCaller transaction/idempotency identity.
event_kind: EventKindClosed event kind.
actor_uuid: Option<Uuid>Optional analyst/agent identity.
recorded_at_micros: i64Injected UTC transaction timestamp in microseconds.
contract_version: u32Event record contract.
Implementations
Sourceimpl ProvenanceEvent
impl ProvenanceEvent
Sourcepub fn new(
operation_uuid: Uuid,
event_kind: EventKind,
actor_uuid: Option<Uuid>,
recorded_at_micros: i64,
) -> Result<Self, ProvenanceError>
pub fn new( operation_uuid: Uuid, event_kind: EventKind, actor_uuid: Option<Uuid>, recorded_at_micros: i64, ) -> Result<Self, ProvenanceError>
Build and identify one canonical event.
Errors
Rejects nil operation/actor UUIDs or canonical encoding failures.
Sourcepub fn canonical_bytes(&self) -> Result<Vec<u8>, ProvenanceError>
pub fn canonical_bytes(&self) -> Result<Vec<u8>, ProvenanceError>
Canonical bytes used for fingerprints and idempotency comparison.
Errors
Returns a canonical encoding failure if shared bounds are exceeded.
Sourcepub fn fingerprint(&self) -> Result<[u8; 32], ProvenanceError>
pub fn fingerprint(&self) -> Result<[u8; 32], ProvenanceError>
Full domain-separated event fingerprint.
Errors
Returns a canonical encoding failure if shared bounds are exceeded.